<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: choosemac.php,v 1.23.2.3 2007/10/02 06:54:46 alec Exp $
 */

$layout['pagetitle'] = trans('Select MAC address');

$p = isset($_GET['p']) ? $_GET['p'] : '';
$js = '';

if(!$p)
	$js = 'var targetfield = window.opener.targetfield;';
elseif($p == 'main')
{
	$js = 'var targetfield = parent.targetfield;';

	$maclist = $LMS->GetMACs();

	if(isset($CONFIG['phpui']['arpd_servers']) && $CONFIG['phpui']['arpd_servers'])
	{
		$servers = explode(' ', eregi_replace("[\t ]+"," ",$CONFIG['phpui']['arpd_servers']));
		foreach($servers as $server)
		{
			$res = explode(':', $server);
			if(!isset($res[1]) || $res[1] == '')
				$res[1] = 1029;
			
			$remote = $LMS->GetRemoteMACs($res[0], $res[1]);
			$maclist = array_merge($maclist, $remote);
		}
	}
	
	$SMARTY->assign('maclist',$maclist);
}

$SMARTY->assign('part', $p);
$SMARTY->assign('js', $js);
$SMARTY->display('choosemac.html');

?>
